Installation of immutable-views project
=======================================

To install the latest released version of the
immutable-views project into your active Python environment:

      $ pip install immutable-views

This will also install any prerequisite Python packages.

For more details and alternative ways to install, see
[Installation](https://immutable-views.readthedocs.io/en/stable/intro.html#installation).
